# Success

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id_token** | **str** | Identity Token | [optional] 
**refresh_token** | **str** | Refresh Token | [optional] 
**cookie** | **str** | Vouch Cookie | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

